# R 2.15.2 GUI 1.53 Leopard build 64-bit (6335)
# The R code accompanying the paper by Vines et al.
# titled Mandated data archiving greatly improves access to research data
# published in FASEBJ (2013)

# the output of the statistical tests has been added (as comments) where deemed useful


# read data file
input <- read.table (file.choose(), sep = ",", T)  
#choose "Vines_et_al_data"

#load the lme4 library
library (lme4)


#these are the column headings
names(input)
# [1] "journal"       "policy_type"   "data_online"   "Impact_Factor"


#set 'journal' and 'policy_type' as factors
input$journal <- as.factor (input$journal)
input$policy_type <- as.factor (input$policy_type)


##################
#First test
#having a policy vs not having a policy (first two paragraphs of 'Statistical Analysis' section)

#create a new factor 'nopolicy_vs_policy'
input$nopolicy_vs_policy<-input$policy_type

#these are the different levels of the nopolicy_vs_policy factor
levels(input$nopolicy_vs_policy)
#[1] "jdap_DS"   "jdap_noDS" "no_policy" "recommend"

#changes 'recommend', 'jdap_noDS', and 'jdap_DS' to 'policy'
levels(input$nopolicy_vs_policy)[c(1,2,4)]<-"policy"

#sets 'no policy' as the reference level
input$nopolicy_vs_policy<-relevel(input$nopolicy_vs_policy, ref="no_policy")


#these are the final levels of the nopolicy_vs_policy factor
levels(input$nopolicy_vs_policy)
#[1] "no_policy" "policy"


#fit a mixed effects logistic regression with journal as a random factor
test1 <- lmer (data_online ~ nopolicy_vs_policy + (1|journal), data = input, family = "binomial")

summary(test1)

# Generalized linear mixed model fit by the Laplace approximation 
# Formula: data_online ~ nopolicy_vs_policy + (1 | journal) 
   # Data: input 
   # AIC   BIC logLik deviance
 # 148.8 159.1 -71.42    142.8
# Random effects:
 # Groups  Name        Variance Std.Dev.
 # journal (Intercept) 3.9472   1.9868  
# Number of obs: 229, groups: journal, 12

# Fixed effects:
                         # Estimate Std. Error z value Pr(>|z|)   
# (Intercept)                -3.784      1.212  -3.122   0.0018 **
# nopolicy_vs_policypolicy    3.222      1.434   2.247   0.0247 * 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1 

# Correlation of Fixed Effects:
            # (Intr)
# nplcy_vs_pl -0.845



# a likelihood ratio test of whether including the factor 'nopolicy_vs_policy' improves the fit of the model
drop1(test1, test="Chisq")

# Single term deletions

# Model:
# data_online ~ nopolicy_vs_policy + (1 | journal)
                   # Df    AIC    LRT Pr(Chi)  
# <none>                148.83                 
# nopolicy_vs_policy  1 151.11 4.2786 0.03859 *
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1 



#the exponential of the Estimate in test1 above (3.222) gives the odds ratio of finding the data online under either policy or no_policy. The odds ratio = 25.07823, so having a policy increased the odds of the data being available online by about 25 times)

exp(3.222)
# [1] 25.07823 

# 95% confidence intervals for this odds ratio - the 1.434 is the Error in test1 for the nopolicy_policy factor
lower<- 3.222 + qnorm(0.025)* 1.434
upper<- 3.222 + qnorm(0.975)* 1.434


exp(cbind(3.222, lower, upper))
               # lower    upper
# [1,] 25.07823 1.508946 416.7924



#######################
# Second test 
#tests for an effect of policy_type on the likelihood of finding data online (see third paragraph of Statistical analysis)


#set 'nopolicy' to be the reference level
input$policy_type <- relevel(input$policy_type, ref="no_policy")

#these are the final levels
levels(input$policy_type)
#[1] "no_policy" "jdap_DS"   "jdap_noDS" "recommend"



test2 <- lmer (data_online ~ policy_type + (1|journal), data = input, family = "binomial")
summary(test2)

# Generalized linear mixed model fit by the Laplace approximation 
# Formula: data_online ~ policy_type + (1 | journal) 
   # Data: input 
 # AIC   BIC logLik deviance
 # 129 146.2 -59.52      119
# Random effects:
 # Groups  Name        Variance   Std.Dev.
 # journal (Intercept) 4.1088e-13 6.41e-07
# Number of obs: 229, groups: journal, 12

# Fixed effects:
                     # Estimate Std. Error z value Pr(>|z|)    
# (Intercept)           -3.3557     0.5873  -5.714 1.11e-08 ***
# policy_typejdap_DS     6.8821     1.1723   5.870 4.35e-09 ***
# policy_typejdap_noDS   2.8449     0.7821   3.638 0.000275 ***
# policy_typerecommend   1.2889     0.6765   1.905 0.056745 .  
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1 

# Correlation of Fixed Effects:
                # (Intr) polcy_typjdp_DS plcy_typjdp_nDS
# polcy_typjdp_DS -0.501                                
# plcy_typjdp_nDS -0.751  0.376                         
# plcy_typrcm     -0.868  0.435           0.652


# likelihood ratio test of whether including the factor 'policy_type' improves the fit of the model
drop1(test2, test="Chisq")

# Single term deletions

# Model:
# data_online ~ policy_type + (1 | journal)
            # Df    AIC    LRT   Pr(Chi)    
# <none>         129.04                     
# policy_type  3 151.11 28.068 3.514e-06 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1 




###############
# we can then calculate the odds ratios for how much better each policy is over no policy (paragraphs 5, 6 and 7 in the Statistical Analysis section)

#these are the Estimates from test2 above
exp(c(1.2889, 2.8449, 6.8821))

	   # recommend	  jdap_noDS	   jdap_DS
# [1]     3.628793    17.199839    974.671021


#calculating the confidence intervals for these odds ratios


# recommend
lower<- 1.2889 + qnorm(0.025)* 0.6765
upper<- 1.2889 + qnorm(0.975)* 0.6765
exp(cbind(1.2889, lower, upper))

                 # lower   upper
# [1,] 3.628793 0.9636611 13.6647  
#CIs contain 1, so there is no significant difference between the likelihood of finding data online for 'no_policy' compared to 'recommend'



# jdap_noDS
lower<- 2.8449 + qnorm(0.025)* 0.7821
upper<- 2.8449 + qnorm(0.975)* 0.7821
exp(cbind(2.8449, lower, upper))

                # lower    upper
# [1,] 17.19984 3.713639 79.66161  
#CIs do not contain 1, so having a 'jdap_noDS' policy is significantly better than 'no_policy'



# jdap_DS

lower<- 6.8821 + qnorm(0.025)* 1.1723
upper<- 6.8821 + qnorm(0.975)* 1.1723
exp(cbind(6.8821, lower, upper))

                # lower    upper
# [1,] 974.671 97.94775 9698.881  
#CIs do not contain 1, so having a 'jdap_DS' policy is much better than 'no_policy"




######## testing for an effect of Impact Factor on data availability  #####

#lmer does not encourage the predictions from the model, so the data need to be reformatted to fit glm. (Using glm on the unformatted data does not account for articles being nested within journal.)

#modelling proportions for each journal

#change online to factor
input$data_online_factor <- replace(input$data_online, which(input$data_online == 0), "not available")
input$data_online_factor <- replace(input$data_online_factor, which(input$data_online == 1), "available")
input$data_online_factor <- factor(input$data_online_factor)

table(input$journal, input$data_online_factor)
            # available not available
  # BJLS              3            10
  # BMC               1            12
  # ConsGen           1            46
  # CropSci           1            11
  # Evolution         3             3
  # Genetica          1             8
  # Heredity          7             0
  # JEB               3             7
  # JHeredity         0            12
  # MolEcol          27             1
  # PloSONE           6            45
  # TAG               0            21
  
mat.online <- matrix(table(input$journal, input$data_online_factor), ncol=2)  #doing a binomial family glm in this format (columns of successes and failures) expects the data to be in a matrix


IFs <- c(2.16, 3.7, 1.25, 2.02, 5.65, 2.35, 4.56, 3.65, 2.24, 6.45, 4.41, 3.26) #just entering the Impact Factors by hand, there are in the same order as in mat.online

model.1 <- glm(mat.online ~ IFs, family = "binomial")
summary(model.1)

# Call:
# glm(formula = mat.online ~ IFs, family = "binomial")

# Deviance Residuals: 
    # Min       1Q   Median       3Q      Max  
# -3.2008  -0.9095   0.7701   1.4331   3.8562  

# Coefficients:
            # Estimate Std. Error z value Pr(>|z|)    
# (Intercept)  -5.9718     0.7781  -7.674 1.66e-14 ***
# IFs           1.1697     0.1692   6.914 4.72e-12 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1 

# (Dispersion parameter for binomial family taken to be 1)

    # Null deviance: 137.736  on 11  degrees of freedom
# Residual deviance:  48.038  on 10  degrees of freedom
# AIC: 72.935

# Number of Fisher Scoring iterations: 5


#Note! The above model is wildly overdispersed (the residual deviance >> the 10 degrees of freedom), but may be unavoidable given the small sample size


#fitting a quasibinomial model instead, this allows the fitting of the dispersion parameter instead of assuming it to be 1.

model.2 <- glm(mat.online ~ IFs, family = "quasibinomial")
summary(model.2) 

# Call:
# glm(formula = mat.online ~ IFs, family = "quasibinomial")

# Deviance Residuals: 
    # Min       1Q   Median       3Q      Max  
# -3.2008  -0.9095   0.7701   1.4331   3.8562  

# Coefficients:
            # Estimate Std. Error t value Pr(>|t|)   
# (Intercept)  -5.9718     1.7730  -3.368  0.00714 **
# IFs           1.1697     0.3855   3.034  0.01259 * 
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1 

# (Dispersion parameter for quasibinomial family taken to be 5.191814)

    # Null deviance: 137.736  on 11  degrees of freedom
# Residual deviance:  48.038  on 10  degrees of freedom
# AIC: NA

# Number of Fisher Scoring iterations: 5


drop1(model.2, test="Chis")
# Single term deletions

# Model:
# mat.online ~ IFs
       # Df Deviance scaled dev.  Pr(>Chi)    
# <none>      48.038                          
# IFs     1  137.736      17.277 3.231e-05 ***



exp(cbind(model.2$coef, confint(model.2)))   
                               # 2.5 %     97.5 %
# (Intercept) 0.002549749 0.0000334241 0.04406655
# IFs         3.220997343 1.7128266520 8.30999392

#so the odds ratio is 3.22 (1.71 - 8.31). For every unit increase in IF, odds of archiving online increase by about 222% (or 3.22 times).

